@@ -34,14 +34,15 @@
 #'   geometry in the `geometry` column.
 #' @param keep_geo_vars if TRUE, keeps all the variables from the Census
 #'   shapefile obtained by tigris.  Defaults to FALSE.
-#' @param shift_geo if TRUE, returns geometry with Alaska and Hawaii shifted for
+#' @param shift_geo (deprecated) if TRUE, returns geometry with Alaska and Hawaii shifted for
 #'   thematic mapping of the entire US. Geometry was originally obtained from
-#'   the albersusa R package.
+#'   the albersusa R package. As of May 2021, we recommend using \code{tigris::shift_geometry()}
+#'   instead.
 #' @param summary_var Character string of a "summary variable" from the ACS to
 #'   be included in your output. Usually a variable (e.g. total population) that
 #'   you'll want to use as a denominator or comparison.
 #' @param key Your Census API key. Obtain one at
-#'   \url{http://api.census.gov/data/key_signup.html}
+#'   \url{https://api.census.gov/data/key_signup.html}
 #' @param moe_level The confidence level of the returned margin of error.  One
 #'   of 90 (the default), 95, or 99.
 #' @param survey The ACS contains one-year, three-year, and five-year surveys
@@ -90,6 +91,10 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
                     shift_geo = FALSE, summary_var = NULL, key = NULL,
                     moe_level = 90, survey = "acs5", show_call = FALSE, ...) {
 
+  if (shift_geo) {
+    warning("The `shift_geo` argument is deprecated and will be removed in a future release. We recommend using `tigris::shift_geometry()` instead.", call. = FALSE)
+  }
+
   if (survey == "acs5" && year < 2009) {
     stop("5-year ACS support in tidycensus begins with the 2005-2009 5-year ACS. Consider using decennial Census data instead.", call. = FALSE)
   }
@@ -192,16 +197,11 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
 
   if (geography == "puma") geography <- "public use microdata area"
 
-  if (geography == "zip code tabulation area" && (!is.null(state) || !is.null(county))) {
+  if (geography == "zip code tabulation area" && !is.null(county)) {
 
     if (year < 2019) {
-      stop("For ACS years prior to 2019, ZCTAs can only be requested for the entire country or by specifying ZCTAs, not within states or counties.",
+      stop("ZCTAs are available by state, but not by county.",
            call. = FALSE)
-    } else {
-      if (!is.null(county)) {
-        stop("ZCTAs for ACS years 2019 and later are available by state, but not by county.",
-             call. = FALSE)
-      }
     }
   }
 
@@ -213,92 +213,97 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
 
   insist_get_acs <- purrr::insistently(get_acs)
 
-  # Allow users to get all block groups in a state
-  # If only one state is specified, get all county FIPS codes in state from tigirs and continue
+  # Allow users to get all block groups in a state (2012 and earlier)
+  # If only one state is specified, get all county FIPS codes in state from tigris and continue
+  if (year < 2013) {
 
-  if ((geography == "block group" && length(state) == 1 && is.null(county))) {
-    st <- suppressMessages(validate_state(state))
+    if ((geography == "block group" && length(state) == 1 && is.null(county))) {
+      st <- suppressMessages(validate_state(state))
+
+      # Get year-specific county IDs from tigris
+      if (year < 2013) {
+        tigris_yr <- 2010
+      } else {
+        tigris_yr <- year
+      }
+
+      cty_year <- suppressMessages(counties(state = st, cb = TRUE,
+                                            resolution = "20m", year = tigris_yr, class = "sf"))
+
+      county <- cty_year$COUNTYFP
 
-    # Get year-specific county IDs from tigris
-    if (year < 2013) {
-      tigris_yr <- 2010
-    } else {
-      tigris_yr <- year
     }
 
-    cty_year <- suppressMessages(counties(state = st, cb = TRUE,
-                                          resolution = "20m", year = tigris_yr, class = "sf"))
+    # If more than one state requested, iterate over the states, calling get_acs and combine results
 
-    county <- cty_year$COUNTYFP
+    if (geography == "block group" && length(state) > 1) {
+
+      if (!is.null(county)) {
+        stop("Don't know which counties belong to which states. County must be null when requesting multiple states.",
+             call. = FALSE)
+      } else {
+
+        message("Fetching block group data by state and county and combining the result.")
+
+        if (geometry) {
+          result <- map(state, ~{
+            suppressMessages(
+              insist_get_acs(geography = geography,
+                             variables = variables,
+                             table = table,
+                             cache_table = cache_table,
+                             year = year,
+                             output = output,
+                             state = .x,
+                             county = county,
+                             zcta = zcta,
+                             summary_var = summary_var,
+                             geometry = geometry,
+                             keep_geo_vars = keep_geo_vars,
+                             shift_geo = FALSE,
+                             key = key,
+                             moe_level = moe_level,
+                             survey = survey,
+                             show_call = show_call))
+          }) %>%
+            reduce(rbind)
+          geoms <- unique(st_geometry_type(result))
+          if (length(geoms) > 1) {
+            result <- st_cast(result, "MULTIPOLYGON")
+          }
+          result <- result %>%
+            as_tibble() %>%
+            st_as_sf()
+        } else {
+          result <- map_df(state, ~{
+            suppressMessages(
+              insist_get_acs(geography = geography,
+                             variables = variables,
+                             table = table,
+                             cache_table = cache_table,
+                             year = year,
+                             output = output,
+                             state = .x,
+                             county = county,
+                             zcta = zcta,
+                             summary_var = summary_var,
+                             geometry = geometry,
+                             keep_geo_vars = keep_geo_vars,
+                             shift_geo = FALSE,
+                             key = key,
+                             moe_level = moe_level,
+                             survey = survey,
+                             show_call = show_call))
+          })
+        }
+
+        return(result)
+      }
+    }
 
   }
 
-  # If more than one state requested, iterate over the states, calling get_acs and combine results
 
-  if (geography == "block group" && length(state) > 1) {
-
-    if (!is.null(county)) {
-      stop("Don't know which counties belong to which states. County must be null when requesting multiple states.",
-           call. = FALSE)
-    } else {
-
-    message("Fetching block group data by state and county and combining the result.")
-
-    if (geometry) {
-      result <- map(state, ~{
-        suppressMessages(
-          insist_get_acs(geography = geography,
-                         variables = variables,
-                         table = table,
-                         cache_table = cache_table,
-                         year = year,
-                         output = output,
-                         state = .x,
-                         county = county,
-                         zcta = zcta,
-                         summary_var = summary_var,
-                         geometry = geometry,
-                         keep_geo_vars = keep_geo_vars,
-                         shift_geo = FALSE,
-                         key = key,
-                         moe_level = moe_level,
-                         survey = survey,
-                         show_call = show_call))
-      }) %>%
-        reduce(rbind)
-      geoms <- unique(st_geometry_type(result))
-      if (length(geoms) > 1) {
-        result <- st_cast(result, "MULTIPOLYGON")
-      }
-      result <- result %>%
-        as_tibble() %>%
-        st_as_sf()
-    } else {
-      result <- map_df(state, ~{
-        suppressMessages(
-          insist_get_acs(geography = geography,
-                         variables = variables,
-                         table = table,
-                         cache_table = cache_table,
-                         year = year,
-                         output = output,
-                         state = .x,
-                         county = county,
-                         zcta = zcta,
-                         summary_var = summary_var,
-                         geometry = geometry,
-                         keep_geo_vars = keep_geo_vars,
-                         shift_geo = FALSE,
-                         key = key,
-                         moe_level = moe_level,
-                         survey = survey,
-                         show_call = show_call))
-      })
-    }
-
-    return(result)
-      }
-    }
 
   # if variables from more than one type of table (e.g. "S1701_C03_002" and "B05002_013"))
   # are requested - take care of this under the hood by having the function
@@ -481,11 +486,11 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
   }
 
 
-  # If more than one state specified for tracts - or more than one county
-  # for block groups - take care of this under the hood by having the function
+  # If more than one state specified for tracts/block groups take care of
+  # this under the hood by having the function
   # call itself and return the result
-  if (geography == "tract" && length(state) > 1) {
-    message("Fetching tract data by state and combining the result.")
+  if ((geography == "tract" || geography == "block group") && length(state) > 1) {
+    message(sprintf("Fetching %s data by state and combining the result.", geography))
     # mc <- match.call(expand.dots = TRUE)
     if (geometry) {
       result <- map(state,~{
@@ -542,62 +547,66 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
     return(result)
   }
 
-  if ((geography == "block group" && length(county) > 1)) {
-    if (geometry) {
-      message("Fetching block group data by county and combining the result.")
-      result <- map(county, ~{
-        suppressMessages(
-          insist_get_acs(geography = geography,
-                variables = variables,
-                table = table,
-                cache_table = cache_table,
-                year = year,
-                output = output,
-                state = state,
-                county = .x,
-                zcta = zcta,
-                summary_var = summary_var,
-                geometry = geometry,
-                keep_geo_vars = keep_geo_vars,
-                shift_geo = FALSE,
-                key = key,
-                moe_level = moe_level,
-                survey = survey,
-                show_call = show_call)) %>%
-          st_cast("MULTIPOLYGON")
-      }) %>%
-        reduce(rbind)
-      geoms <- unique(st_geometry_type(result))
-      if (length(geoms) > 1) {
-        result <- st_cast(result, "MULTIPOLYGON")
+  # This should be cleaned up and combined with some of the code earlier up
+  # but we still need to iterate through counties for block groups earlier than 2013
+  if (year < 2013) {
+    if ((geography == "block group" && length(county) > 1)) {
+      if (geometry) {
+        message("Fetching block group data by county and combining the result.")
+        result <- map(county, ~{
+          suppressMessages(
+            insist_get_acs(geography = geography,
+                           variables = variables,
+                           table = table,
+                           cache_table = cache_table,
+                           year = year,
+                           output = output,
+                           state = state,
+                           county = .x,
+                           zcta = zcta,
+                           summary_var = summary_var,
+                           geometry = geometry,
+                           keep_geo_vars = keep_geo_vars,
+                           shift_geo = FALSE,
+                           key = key,
+                           moe_level = moe_level,
+                           survey = survey,
+                           show_call = show_call)) %>%
+            st_cast("MULTIPOLYGON")
+        }) %>%
+          reduce(rbind)
+        geoms <- unique(st_geometry_type(result))
+        if (length(geoms) > 1) {
+          result <- st_cast(result, "MULTIPOLYGON")
+        }
+        result <- result %>%
+          as_tibble() %>%
+          st_as_sf()
+      } else {
+        message("Fetching block group data by county and combining the result.")
+        result <- map_df(county, ~{
+          suppressMessages(
+            insist_get_acs(geography = geography,
+                           variables = variables,
+                           table = table,
+                           cache_table = cache_table,
+                           year = year,
+                           output = output,
+                           state = state,
+                           county = .x,
+                           zcta = zcta,
+                           summary_var = summary_var,
+                           geometry = geometry,
+                           keep_geo_vars = keep_geo_vars,
+                           shift_geo = FALSE,
+                           key = key,
+                           moe_level = moe_level,
+                           survey = survey,
+                           show_call = show_call))
+        })
       }
-      result <- result %>%
-        as_tibble() %>%
-        st_as_sf()
-    } else {
-      message("Fetching block group data by county and combining the result.")
-      result <- map_df(county, ~{
-        suppressMessages(
-          insist_get_acs(geography = geography,
-                variables = variables,
-                table = table,
-                cache_table = cache_table,
-                year = year,
-                output = output,
-                state = state,
-                county = .x,
-                zcta = zcta,
-                summary_var = summary_var,
-                geometry = geometry,
-                keep_geo_vars = keep_geo_vars,
-                shift_geo = FALSE,
-                key = key,
-                moe_level = moe_level,
-                survey = survey,
-                show_call = show_call))
-      })
+      return(result)
     }
-    return(result)
   }
 
   if (moe_level == 90) {
@@ -764,8 +773,8 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
     dat2[dat2 == -999999999] <- NA
   }
 
-  # For ZCTAs 2019 and later, strip the state code from GEOID (issue #338)
-  if (geography == "zip code tabulation area" && year > 2018) {
+  # For ZCTAs, strip the state code from GEOID (issue #338 and #358)
+  if (geography == "zip code tabulation area" && year > 2012) {
     dat2 <- dat2 %>%
       dplyr::mutate(
         GEOID = stringr::str_sub(GEOID, start = 3L)
@@ -803,8 +812,12 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
 
     } else {
 
-      geom <- suppressMessages(use_tigris(geography = geography, year = year,
-                                          state = state, county = county, ...))
+      geom <- try(suppressMessages(use_tigris(geography = geography, year = year,
+                                          state = state, county = county, ...)))
+
+      if ("try-error" %in% class(geom)) {
+        stop("Your geometry data download failed. Please try again later or check the status of the Census Bureau website at https://www2.census.gov/geo/tiger/", call. = FALSE)
+      }
     }
 
     if (! keep_geo_vars) {
